conText-package: conText: 'a la Carte' on Text (ConText) Embedding Regression

conText-packageR Documentation

conText: 'a la Carte' on Text (ConText) Embedding Regression

Description

A fast, flexible and transparent framework to estimate context-specific word and short document embeddings using the 'a la carte' embeddings approach developed by Khodak et al. (2018) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.1805.05388")} and evaluate hypotheses about covariate effects on embeddings using the regression framework developed by Rodriguez et al. (2021)\Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/S0003055422001228")}. New version of the package applies a new estimator to measure the distance between word embeddings as described in Green et al. (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/pan.2024.22")}.

Author(s)

Maintainer: Sofia Avila sofiaavila@princeton.edu (ORCID)

Authors:

Other contributors:

See Also

Useful links:


conText documentation built on April 12, 2026, 9:06 a.m.